====
spym
====

``spym`` is a Python package for processing Scanning Probe Microscopy (SPM) data, which best integrates with xarray, providing an accessor extension to its *DataArrays* and *Datasets*.


.. toctree::
   :caption: Contents
   :maxdepth: 1
   
   installation
   usage


``spym`` is part of the `reScipy project <https://rescipy-project.readthedocs.io>`_.


Feedback
========

Please report any feedback, bugs, or feature requests by opening an issue on the `issue tracker <https://github.com/mpanighel/spym/issues>`_ of the code repository. You should provide as much information as possible to reproduce the problem, and details of your desiderata.
